=====
pycellfit
=====

Project Description
--------
**pycellfit**: an open-source Python implementation of the CellFIT method of inferring cellular forces developed by Brodland et al.

**Author**: Nilai Vemula, Vanderbilt University (working under Dr. Shane Hutson, Vanderbilt University)

**Project Goal**: To develop an open-source version of CellFIT, a toolkit for inferring tensions along cell membranes and pressures inside cells based on cell geometries and their curvilinear boundaries. (See [1]_.)

**Project Timeline**: Initial project started in August 2019 with work based off of XJ Xu. This repository was re-made in May 2020 in order to restart repository structure.

**Project Status**: **Early development**

Getting Started
--------
This project *will* be available on PyPI. For now, simply clone this repository and ... ??

Features
--------
This section will include a list of features available in the package and maybe a check-list of things to add

Examples
--------
This section will walk through an example of the basic pycellfit pipeline.

Future Goals
--------
The final implementation of pycellfit will be as a web-app based on the Django framework.

References
--------
.. [1] Brodland GW, Veldhuis JH, Kim S, Perrone M, Mashburn D, et al. (2014) CellFIT: A Cellular Force-Inference Toolkit Using Curvilinear Cell Boundaries. PLOS ONE 9(6): e99116. https://doi.org/10.1371/journal.pone.0099116

